#include <stdio.h>
#include <stdlib.h>
#include <pango/pangocairo.h>

#define W 200
#define H 50

void
usage(char* name) {
	fprintf(stderr,"usage: %s [-a] out.png\n",name);
	exit(1);
}

void
draw(cairo_t *cr, int aflag) {
	PangoLayout *layout;
	PangoFontDescription *desc;
	int y0=10, fontsize=20;

	/* draw two lines at y=10 and y=30 */
	cairo_set_source_rgb(cr, 0.0, 0.0, 0.0);
	cairo_set_line_width(cr, 2);

	cairo_move_to(cr, 0, y0);
	cairo_rel_line_to(cr, W, 0);
	cairo_move_to(cr, 0, y0+fontsize);
	cairo_rel_line_to(cr, W, 0);

	cairo_stroke(cr);

	/* draw a text, either 20 point or 20 pixel */
	layout = pango_cairo_create_layout(cr);
	pango_layout_set_text(layout, "acbdgj XY 80", -1);

	desc = pango_font_description_from_string("Times 20");
	if(aflag)
		pango_font_description_set_absolute_size(desc, PANGO_SCALE*fontsize);
	else
		pango_font_description_set_size(desc, PANGO_SCALE*fontsize);
	pango_layout_set_font_description(layout, desc);
	pango_font_description_free(desc);

	cairo_translate(cr, 0, y0);
	pango_cairo_update_layout(cr, layout);
	pango_cairo_show_layout(cr, layout);

	g_object_unref(layout);
}

int
main(int argc, char* argv[]) {
	int aflag = 0;
	char *fname;
	cairo_t *cr;
	cairo_surface_t *surface;
	cairo_status_t status;
	
	if(argc == 1)
		usage(argv[0]);
	if( argv[1][0] == '-' && argv[1][1] == 'a' ) {
		aflag = 1;
		if( argc == 2 )
			usage(argv[0]);
		fname = argv[2];
	}
	else
		fname = argv[1];

	surface = cairo_image_surface_create(CAIRO_FORMAT_ARGB32, W, H);
	cr = cairo_create(surface);
	cairo_set_source_rgb(cr, 1.0, 1.0, 1.0);
	cairo_paint(cr);

	draw(cr, aflag);
	
	cairo_destroy(cr);
	status = cairo_surface_write_to_png(surface, fname);
	cairo_surface_destroy(surface);	

	return (status != CAIRO_STATUS_SUCCESS);
}
